@@ -1,8 +1,12 @@
+#![no_std]
+
 pub use ach_array as array;
 pub use ach_cell as cell;
 pub use ach_lazy as lazy;
 pub use ach_mpmc as mpmc;
 pub use ach_once as once;
+pub use ach_option as option;
+pub use ach_pool as pool;
 pub use ach_pubsub as pubsub;
 pub use ach_ring as ring;
 pub use ach_spsc as spsc;
